#!/bin/bash
#Automatically Created by buildpkg 1.1.0
#Maintainer: fushark <fushark@yahoo.com>
#url: http://udeproject.sourceforge.net/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_old_builds () {
	for COMPLETED in $package.{tgz,md5,dep} src pkg; do
		if [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_complaince() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			. $desktop 2>/dev/null
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					. $desktop 2>/dev/null
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}

gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	if [ -d "$startdir/pkg/usr/bin" ]; then
		chown -R root:root $startdir/pkg/usr/bin
	fi
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
}

create_package() {
	cd $startdir/pkg
	makepkg -l y -c n $startdir/$package.tgz
	cd $startdir
	md5sum $package.tgz > $startdir/$package.md5
}

#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	for SOURCES in http://downloads.sourceforge.net/udeproject/ude-0.2.9b.tar.gz ude.desktop xinitrc.ude appmenu uwmrc-behaviour.hook uwmrc-layout.hook uwmrc-ws.hook zw.xpm; do
		if [ ! -f "$(basename $SOURCES)" ]; then
			protocol=$(echo $SOURCES | sed 's|:.*||')
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
				wget $SOURCES
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $(basename $SOURCES) $startdir/src
	done
	mkdir $startdir/pkg
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in *; do
			if [[ "$(echo $FILES | grep tar)" ]]; then
				tar xf $FILES
			fi
		done
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
        #Copy the ude desktop file
        cd $startdir/pkg
        mkdir -p etc/X11/dm/Sessions
        cp $startdir/src/ude.desktop $startdir/pkg/etc/X11/dm/Sessions/
        
        #Copy ude xinitrc file
        cd $startdir/pkg
        mkdir -p etc/X11/xinit
        cp $startdir/src/xinitrc.ude $startdir/pkg/etc/X11/xinit/
        chmod +x $startdir/pkg/etc/X11/xinit/xinitrc.ude
        
        #Begin compiling
        cd $startdir/src/$pkgname-$pkgver
        ./configure --prefix=/usr --localstatedir=/var --sysconfdir=/etc
        make || return 1
        make DESTDIR=$startdir/pkg install
        
        #Replace the appmenu
        rm -f $startdir/pkg/usr/share/ude/config/appmenu
        cp $startdir/src/appmenu $startdir/pkg/usr/share/ude/config/
        
        #Replace the uwmrc files
        rm -f $startdir/pkg/usr/share/ude/config/uwmrc-*.hook
        cp $startdir/src/uwmrc-*.hook $startdir/pkg/usr/share/ude/config/
        
        #Copy a zenwalk wallpaper into the gfx folder
        cp $startdir/src/zw.xpm $startdir/pkg/usr/share/ude/gfx/
}

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
ude: ude - Unix Desktop Environment
ude: 
ude: UDE attempts to create a new Desktop Environment for X11. The entirely
ude: original look & feel is mainly optimized for efficient shell usage (as
ude: for programming, sysadministration etc). Offers max. screen space,
ude: stability and very low resource usage.
ude:  
ude: Contact Christian Rupert: arc_at_users.sourceforge.net
ude: 
ude: 
ude: 
EODESC
}

copy_docs() {
	for stuff in AUTHORS COPYING ChangeLog INSTALL NEWS README REQUIREMENTS; do
		if [ ! -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
			mkdir -p $startdir/pkg/usr/doc/$pkgname-$pkgver
		fi
		find $startdir/src -type f -iname "$stuff" -exec cp -R '{}' $startdir/pkg/usr/doc/$pkgname-$pkgver \;
	done
}
detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(requiredbuilder -z $startdir/$package.tgz)
	
	depstring=$depends
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=ude
pkgver=0.2.9b
pkgrel=2
zenver=48
arch=i486
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
export CFLAGS="-O2 -march=$arch -mtune=i686"
export CXXFLAGS="-O2 -march=$arch -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
copy_docs
check_for_menu_complaince
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
detect_dependencies
echo "Package has been built."
